pub struct LinePrinter { /* private fields */ }Expand description
use to print a single line, properly handle the tabstop and shift of a string
e.g. a long line will be printed as ..some content or some content.. or ..some content..
depends on the container’s width and the size of the content.
let's say we have a very long line with lots of useless information
|.. with lots of use..| // only to show this
|<- container width ->|
|<- shift -> |
|< hscroll >|Implementations
Sourceimpl LinePrinter
impl LinePrinter
pub fn builder() -> Self
pub fn row(self, row: usize) -> Self
pub fn col(self, col: usize) -> Self
pub fn tabstop(self, tabstop: usize) -> Self
pub fn hscroll_offset(self, offset: i64) -> Self
pub fn text_width(self, width: usize) -> Self
pub fn container_width(self, width: usize) -> Self
pub fn shift(self, shift: usize) -> Self
pub fn build(self) -> Self
pub fn reset(&mut self)
pub fn print_char( &mut self, canvas: &mut dyn Canvas, ch: char, attr: Attr, skip: bool, )